@@ -26,7 +26,6 @@ describe 'oslo::db' do
         is_expected.to contain_keystone_config('database/db_inc_retry_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/db_max_retry_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/db_max_retries').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('database/use_tpool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/mysql_enable_ndb').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -51,7 +50,6 @@ describe 'oslo::db' do
           :db_inc_retry_interval   => true,
           :db_max_retry_interval   => '10',
           :db_max_retries          => '20',
-          :use_tpool               => true,
           :mysql_enable_ndb        => true,
         }
       end
@@ -73,46 +71,10 @@ describe 'oslo::db' do
         is_expected.to contain_keystone_config('custom_group/db_inc_retry_interval').with_value(true)
         is_expected.to contain_keystone_config('custom_group/db_max_retry_interval').with_value('10')
         is_expected.to contain_keystone_config('custom_group/db_max_retries').with_value('20')
-        is_expected.to contain_keystone_config('custom_group/use_tpool').with_value(true)
         is_expected.to contain_keystone_config('custom_group/mysql_enable_ndb').with_value(true)
       end
     end
 
-    context 'with mongodb backend' do
-      let :params do
-        { :connection => 'mongodb://localhost:1234/db' }
-      end
-
-      it 'install the proper backend package' do
-        is_expected.to contain_package(platform_params[:pymongo_package_name]).with(
-          :ensure => 'present',
-          :name   => platform_params[:pymongo_package_name],
-          :tag    => 'openstack'
-        )
-      end
-
-      context 'with backend package management disabled' do
-        before do
-          params.merge!({
-            :manage_backend_package => false,
-          })
-        end
-
-        it 'does not install backend package' do
-          is_expected.not_to contain_package('python-pymongo')
-        end
-      end
-    end
-
-    context 'with specific mongodb connection string' do
-      let :params do
-        { :connection => 'mongodb://user:password@host1:27017,host2:27017,host3:27017/db_name?replicaSet=replica&readPreference=primaryPreferred' }
-      end
-
-      it { is_expected.to contain_keystone_config('database/connection').with_value(
-        'mongodb://user:password@host1:27017,host2:27017,host3:27017/db_name?replicaSet=replica&readPreference=primaryPreferred').with_secret(true) }
-    end
-
     context 'with pymysql connection' do
       let :params do
         { :connection => 'mysql+pymysql://db:db@localhost/db' }
@@ -122,24 +84,6 @@ describe 'oslo::db' do
       it { is_expected.to contain_keystone_config('database/connection').with_value('mysql+pymysql://db:db@localhost/db').with_secret(true) }
     end
 
-    context 'with incorrect database_connection string' do
-      let :params do
-        { :connection => 'foo://db:db@localhost/db', }
-      end
-
-      it { should raise_error(Puppet::Error) }
-    end
-
-    context 'with incorrect pymysql database_connection string' do
-      let :params do
-        { :connection => 'foo+pymysql://db:db@localhost/db', }
-      end
-
-      it { should raise_error(Puppet::Error) }
-    end
-  end
-
-  shared_examples 'oslo-db with postgresql' do
     context 'with postgresql backend' do
       let :params do
         { :connection => 'postgresql://db:db@localhost/db', }
@@ -169,6 +113,22 @@ describe 'oslo::db' do
 
       it { is_expected.to contain_keystone_config('database/connection').with_value('postgresql+psycopg2://db:db@localhost/db').with_secret(true) }
     end
+
+    context 'with incorrect database_connection string' do
+      let :params do
+        { :connection => 'foo://db:db@localhost/db', }
+      end
+
+      it { should raise_error(Puppet::Error) }
+    end
+
+    context 'with incorrect pymysql database_connection string' do
+      let :params do
+        { :connection => 'foo+pymysql://db:db@localhost/db', }
+      end
+
+      it { should raise_error(Puppet::Error) }
+    end
   end
 
   shared_examples 'oslo-db on Debian' do
@@ -238,7 +198,11 @@ describe 'oslo::db' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
+        }))
       end
 
       let (:platform_params) do
@@ -259,10 +223,6 @@ describe 'oslo::db' do
       end
 
       it_behaves_like 'oslo-db'
-      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
-      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
-        it_behaves_like 'oslo-db with postgresql'
-      end
       it_behaves_like "oslo-db on #{facts[:osfamily]}"
     end
   end
