@@ -8,6 +8,8 @@ describe 'oslo::policy' do
 
     context 'with default parameters' do
       it 'configure oslo_policy default params' do
+        is_expected.to contain_keystone_config('oslo_policy/enforce_scope').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('oslo_policy/enforce_new_defaults').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('oslo_policy/policy_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('oslo_policy/policy_default_rule').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('oslo_policy/policy_dirs').with_value('<SERVICE DEFAULT>')
@@ -17,28 +19,20 @@ describe 'oslo::policy' do
     context 'with overridden parameters' do
       let :params do
         {
-          :policy_file         => '/path/to/policy.file',
-          :policy_default_rule => 'some rule',
-          :policy_dirs         => ['dir1', '/dir/2'],
+          :enforce_scope        => false,
+          :enforce_new_defaults => false,
+          :policy_file          => '/path/to/policy.file',
+          :policy_default_rule  => 'some rule',
+          :policy_dirs          => 'dir1',
         }
       end
 
       it 'configures oslo_policy section' do
+        is_expected.to contain_keystone_config('oslo_policy/enforce_scope').with_value(false)
+        is_expected.to contain_keystone_config('oslo_policy/enforce_new_defaults').with_value(false)
         is_expected.to contain_keystone_config('oslo_policy/policy_file').with_value('/path/to/policy.file')
         is_expected.to contain_keystone_config('oslo_policy/policy_default_rule').with_value('some rule')
-        is_expected.to contain_keystone_config('oslo_policy/policy_dirs').with_value('dir1,/dir/2')
-      end
-    end
-
-    context 'with string in list parameters' do
-      let :params do
-        {
-          :policy_dirs => 'dir1,/dir/2',
-        }
-      end
-
-      it 'configures oslo_policy section with overridden list values as strings' do
-        is_expected.to contain_keystone_config('oslo_policy/policy_dirs').with_value('dir1,/dir/2')
+        is_expected.to contain_keystone_config('oslo_policy/policy_dirs').with_value('dir1')
       end
     end
   end
